@@ -425,6 +425,8 @@ ev_job_links_new (EvDocument *document)
  * Get a #GtkTreeModel loaded with the links
  *
  * Return value: (transfer none): The #GtkTreeModel loaded
+ *
+ * Since: 3.6
  */
 GtkTreeModel *
 ev_job_links_get_model (EvJobLinks *job)
@@ -747,6 +749,10 @@ ev_job_page_data_run (EvJob *job)
 						  ev_page,
 						  &(job_pd->text_layout),
 						  &(job_pd->text_layout_length));
+	if ((job_pd->flags & EV_PAGE_DATA_INCLUDE_TEXT_ATTRS) && EV_IS_DOCUMENT_TEXT (job->document))
+		job_pd ->text_attrs =
+			ev_document_text_get_text_attrs (EV_DOCUMENT_TEXT (job->document),
+							 ev_page);
         if ((job_pd->flags & EV_PAGE_DATA_INCLUDE_TEXT_LOG_ATTRS) && job_pd->text) {
                 job_pd->text_log_attrs_length = g_utf8_strlen (job_pd->text, -1);
                 job_pd->text_log_attrs = g_new0 (PangoLogAttr, job_pd->text_log_attrs_length + 1);
@@ -890,6 +896,13 @@ ev_job_thumbnail_new (EvDocument *document,
 	return EV_JOB (job);
 }
 
+/**
+ * ev_job_thumbnail_set_has_frame:
+ * @job:
+ * @has_frame:
+ *
+ * Since: 3.8
+ */
 void
 ev_job_thumbnail_set_has_frame (EvJobThumbnail  *job,
                                 gboolean         has_frame)
@@ -1650,6 +1663,13 @@ ev_job_find_new (EvDocument  *document,
 	return EV_JOB (job);
 }
 
+/**
+ * ev_job_find_set_options:
+ * @job:
+ * @options:
+ *
+ * Since: 3.6
+ */
 void
 ev_job_find_set_options (EvJobFind     *job,
                          EvFindOptions  options)
@@ -1659,6 +1679,14 @@ ev_job_find_set_options (EvJobFind     *job,
         job->case_sensitive = options & EV_FIND_CASE_SENSITIVE;
 }
 
+/**
+ * ev_job_find_get_options:
+ * @job:
+ *
+ * Returns: the job's find options
+ *
+ * Since: 3.6
+ */
 EvFindOptions
 ev_job_find_get_options (EvJobFind *job)
 {
