@@ -188,7 +188,6 @@ struct _EvView {
 	guint selection_update_id;
 	guint selection_scroll_id;
 
-	EvViewSelectionMode selection_mode;
 	SelectionInfo selection_info;
 
 	/* Copy link address selection */
@@ -270,6 +269,10 @@ void _ev_view_transform_doc_rect_to_view_rect (EvView       *view,
 void _ev_view_get_selection_colors (EvView  *view,
 				    GdkRGBA *bg_color,
 				    GdkRGBA *fg_color);
+gint _ev_view_get_caret_cursor_offset_at_doc_point (EvView *view,
+						    gint    page,
+						    gdouble doc_x,
+						    gdouble doc_y);
 
 #endif  /* __EV_VIEW_PRIVATE_H__ */
 
