@@ -36,15 +36,13 @@ G_BEGIN_DECLS
 #define EV_TYPE_VIEW            (ev_view_get_type ())
 #define EV_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EV_TYPE_VIEW, EvView))
 #define EV_IS_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EV_TYPE_VIEW))
+#define EV_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), EV_TYPE_VIEW, EvViewClass))
+#define EV_IS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EV_TYPE_VIEW))
+#define EV_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), EV_TYPE_VIEW, EvViewClass))
 
 typedef struct _EvView       EvView;
 typedef struct _EvViewClass  EvViewClass;
 
-typedef enum {
-	EV_VIEW_SELECTION_TEXT,
-	EV_VIEW_SELECTION_RECTANGLE,
-} EvViewSelectionMode;
-
 GType		ev_view_get_type	    (void) G_GNUC_CONST;
 
 GtkWidget*	ev_view_new		    (void);
@@ -97,6 +95,7 @@ void           ev_view_hide_cursor        (EvView         *view);
 void           ev_view_show_cursor        (EvView         *view);
 
 /* Navigation */
+EV_DEPRECATED_FOR(g_signal_emit_by_name)
 void	       ev_view_scroll             (EvView         *view,
 	                                   GtkScrollType   scroll,
 					   gboolean        horizontal);
@@ -120,10 +119,13 @@ void           ev_view_begin_add_annotation  (EvView          *view,
 void           ev_view_cancel_add_annotation (EvView          *view);
 
 /* Caret navigation */
+gboolean       ev_view_supports_caret_navigation    (EvView  *view);
 gboolean       ev_view_is_caret_navigation_enabled  (EvView  *view);
 void           ev_view_set_caret_navigation_enabled (EvView  *view,
                                                      gboolean enabled);
-
+void           ev_view_set_caret_cursor_position    (EvView  *view,
+                                                     guint    page,
+                                                     guint    offset);
 G_END_DECLS
 
 #endif /* __EV_VIEW_H__ */
