@@ -72,7 +72,7 @@ static void ev_sidebar_attachments_page_iface_init (EvSidebarPageInterface *ifac
 
 G_DEFINE_TYPE_EXTENDED (EvSidebarAttachments,
                         ev_sidebar_attachments,
-                        GTK_TYPE_VBOX,
+                        GTK_TYPE_BOX,
                         0, 
                         G_IMPLEMENT_INTERFACE (EV_TYPE_SIDEBAR_PAGE, 
 					       ev_sidebar_attachments_page_iface_init))
@@ -568,8 +568,7 @@ ev_sidebar_attachments_init (EvSidebarAttachments *ev_attachbar)
 	gtk_container_add (GTK_CONTAINER (swindow),
 			   ev_attachbar->priv->icon_view);
 
-	gtk_container_add (GTK_CONTAINER (ev_attachbar),
-			   swindow);
+        gtk_box_pack_start (GTK_BOX (ev_attachbar), swindow, TRUE, TRUE, 0);
 	gtk_widget_show_all (GTK_WIDGET (ev_attachbar));
 
 	/* Icon Theme */
@@ -600,7 +599,9 @@ ev_sidebar_attachments_new (void)
 {
 	GtkWidget *ev_attachbar;
 
-	ev_attachbar = g_object_new (EV_TYPE_SIDEBAR_ATTACHMENTS, NULL);
+	ev_attachbar = g_object_new (EV_TYPE_SIDEBAR_ATTACHMENTS,
+                                     "orientation", GTK_ORIENTATION_VERTICAL,
+                                     NULL);
 
 	return ev_attachbar;
 }
